from enum import Enum

__NAMESPACE__ = "https://www.aade.gr/myDATA/expensesClassificaton/v1.0"


class ExpensesClassificationCategory(Enum):
    CATEGORY2_1 = "category2_1"
    CATEGORY2_2 = "category2_2"
    CATEGORY2_3 = "category2_3"
    CATEGORY2_4 = "category2_4"
    CATEGORY2_5 = "category2_5"
    CATEGORY2_6 = "category2_6"
    CATEGORY2_7 = "category2_7"
    CATEGORY2_8 = "category2_8"
    CATEGORY2_9 = "category2_9"
    CATEGORY2_10 = "category2_10"
    CATEGORY2_11 = "category2_11"
    CATEGORY2_12 = "category2_12"
    CATEGORY2_13 = "category2_13"
    CATEGORY2_14 = "category2_14"
    CATEGORY2_95 = "category2_95"
